All of lore.kernel.org
 help / color / mirror / Atom feed
From: Sebastian Andrzej Siewior <bigeasy@linutronix.de>
To: linux-kernel@vger.kernel.org
Cc: tglx@linutronix.de, Peter Zijlstra <peterz@infradead.org>,
	Sebastian Andrzej Siewior <bigeasy@linutronix.de>,
	Zefan Li <lizefan.x@bytedance.com>, Tejun Heo <tj@kernel.org>,
	Johannes Weiner <hannes@cmpxchg.org>,
	cgroups@vger.kernel.org
Subject: [PATCH 24/38] cgroup: Replace deprecated CPU-hotplug functions.
Date: Tue,  3 Aug 2021 16:16:07 +0200	[thread overview]
Message-ID: <20210803141621.780504-25-bigeasy@linutronix.de> (raw)
In-Reply-To: <20210803141621.780504-1-bigeasy@linutronix.de>

The functions get_online_cpus() and put_online_cpus() have been
deprecated during the CPU hotplug rework. They map directly to
cpus_read_lock() and cpus_read_unlock().

Replace deprecated CPU-hotplug functions with the official version.
The behavior remains unchanged.

Cc: Zefan Li <lizefan.x@bytedance.com>
Cc: Tejun Heo <tj@kernel.org>
Cc: Johannes Weiner <hannes@cmpxchg.org>
Cc: cgroups@vger.kernel.org
Signed-off-by: Sebastian Andrzej Siewior <bigeasy@linutronix.de>
---
 kernel/cgroup/cpuset.c | 30 +++++++++++++++---------------
 1 file changed, 15 insertions(+), 15 deletions(-)

diff --git a/kernel/cgroup/cpuset.c b/kernel/cgroup/cpuset.c
index adb5190c44296..bd2b998249e8b 100644
--- a/kernel/cgroup/cpuset.c
+++ b/kernel/cgroup/cpuset.c
@@ -979,7 +979,7 @@ partition_and_rebuild_sched_domains(int ndoms_new, cpumask_var_t doms_new[],
  * 'cpus' is removed, then call this routine to rebuild the
  * scheduler's dynamic sched domains.
  *
  * Call with cpuset_mutex held.  Takes get_online_cpus().
  */
 static void rebuild_sched_domains_locked(void)
 {
@@ -1040,11 +1040,11 @@ static void rebuild_sched_domains_locked(void)
 
 void rebuild_sched_domains(void)
 {
-	get_online_cpus();
+	cpus_read_lock();
 	percpu_down_write(&cpuset_rwsem);
 	rebuild_sched_domains_locked();
 	percpu_up_write(&cpuset_rwsem);
-	put_online_cpus();
+	cpus_read_unlock();
 }
 
 /**
@@ -2282,7 +2282,7 @@ static int cpuset_write_u64(struct cgroup_subsys_state *css, struct cftype *cft,
 	cpuset_filetype_t type = cft->private;
 	int retval = 0;
 
-	get_online_cpus();
+	cpus_read_lock();
 	percpu_down_write(&cpuset_rwsem);
 	if (!is_cpuset_online(cs)) {
 		retval = -ENODEV;
@@ -2320,7 +2320,7 @@ static int cpuset_write_u64(struct cgroup_subsys_state *css, struct cftype *cft,
 	}
 out_unlock:
 	percpu_up_write(&cpuset_rwsem);
-	put_online_cpus();
+	cpus_read_unlock();
 	return retval;
 }
 
@@ -2331,7 +2331,7 @@ static int cpuset_write_s64(struct cgroup_subsys_state *css, struct cftype *cft,
 	cpuset_filetype_t type = cft->private;
 	int retval = -ENODEV;
 
-	get_online_cpus();
+	cpus_read_lock();
 	percpu_down_write(&cpuset_rwsem);
 	if (!is_cpuset_online(cs))
 		goto out_unlock;
@@ -2346,7 +2346,7 @@ static int cpuset_write_s64(struct cgroup_subsys_state *css, struct cftype *cft,
 	}
 out_unlock:
 	percpu_up_write(&cpuset_rwsem);
-	put_online_cpus();
+	cpus_read_unlock();
 	return retval;
 }
 
@@ -2385,7 +2385,7 @@ static ssize_t cpuset_write_resmask(struct kernfs_open_file *of,
 	kernfs_break_active_protection(of->kn);
 	flush_work(&cpuset_hotplug_work);
 
-	get_online_cpus();
+	cpus_read_lock();
 	percpu_down_write(&cpuset_rwsem);
 	if (!is_cpuset_online(cs))
 		goto out_unlock;
@@ -2411,7 +2411,7 @@ static ssize_t cpuset_write_resmask(struct kernfs_open_file *of,
 	free_cpuset(trialcs);
 out_unlock:
 	percpu_up_write(&cpuset_rwsem);
-	put_online_cpus();
+	cpus_read_unlock();
 	kernfs_unbreak_active_protection(of->kn);
 	css_put(&cs->css);
 	flush_workqueue(cpuset_migrate_mm_wq);
@@ -2542,7 +2542,7 @@ static ssize_t sched_partition_write(struct kernfs_open_file *of, char *buf,
 		return -EINVAL;
 
 	css_get(&cs->css);
-	get_online_cpus();
+	cpus_read_lock();
 	percpu_down_write(&cpuset_rwsem);
 	if (!is_cpuset_online(cs))
 		goto out_unlock;
@@ -2550,7 +2550,7 @@ static ssize_t sched_partition_write(struct kernfs_open_file *of, char *buf,
 	retval = update_prstate(cs, val);
 out_unlock:
 	percpu_up_write(&cpuset_rwsem);
-	put_online_cpus();
+	cpus_read_unlock();
 	css_put(&cs->css);
 	return retval ?: nbytes;
 }
@@ -2756,7 +2756,7 @@ static int cpuset_css_online(struct cgroup_subsys_state *css)
 	if (!parent)
 		return 0;
 
-	get_online_cpus();
+	cpus_read_lock();
 	percpu_down_write(&cpuset_rwsem);
 
 	set_bit(CS_ONLINE, &cs->flags);
@@ -2809,7 +2809,7 @@ static int cpuset_css_online(struct cgroup_subsys_state *css)
 	spin_unlock_irq(&callback_lock);
 out_unlock:
 	percpu_up_write(&cpuset_rwsem);
-	put_online_cpus();
+	cpus_read_unlock();
 	return 0;
 }
 
@@ -2828,7 +2828,7 @@ static void cpuset_css_offline(struct cgroup_subsys_state *css)
 {
 	struct cpuset *cs = css_cs(css);
 
-	get_online_cpus();
+	cpus_read_lock();
 	percpu_down_write(&cpuset_rwsem);
 
 	if (is_partition_root(cs))
@@ -2849,7 +2849,7 @@ static void cpuset_css_offline(struct cgroup_subsys_state *css)
 	clear_bit(CS_ONLINE, &cs->flags);
 
 	percpu_up_write(&cpuset_rwsem);
-	put_online_cpus();
+	cpus_read_unlock();
 }
 
 static void cpuset_css_free(struct cgroup_subsys_state *css)
@@ -979,7 +979,7 @@ partition_and_rebuild_sched_domains(int ndoms_new, cpumask_var_t doms_new[],
  * scheduler's dynamic sched domains.
  *
- * Call with cpuset_mutex held.  Takes get_online_cpus().
+ * Call with cpuset_mutex held.  Takes cpus_read_lock().
  */
 static void rebuild_sched_domains_locked(void)
-- 
2.32.0


WARNING: multiple messages have this Message-ID (diff)
From: Sebastian Andrzej Siewior <bigeasy-hfZtesqFncYOwBW4kG4KsQ@public.gmane.org>
To: linux-kernel-u79uwXL29TY76Z2rM5mHXA@public.gmane.org
Cc: tglx-hfZtesqFncYOwBW4kG4KsQ@public.gmane.org,
	Peter Zijlstra <peterz-wEGCiKHe2LqWVfeAwA7xHQ@public.gmane.org>,
	Sebastian Andrzej Siewior
	<bigeasy-hfZtesqFncYOwBW4kG4KsQ@public.gmane.org>,
	Zefan Li <lizefan.x-EC8Uxl6Npydl57MIdRCFDg@public.gmane.org>,
	Tejun Heo <tj-DgEjT+Ai2ygdnm+yROfE0A@public.gmane.org>,
	Johannes Weiner <hannes-druUgvl0LCNAfugRpC6u6w@public.gmane.org>,
	cgroups-u79uwXL29TY76Z2rM5mHXA@public.gmane.org
Subject: [PATCH 24/38] cgroup: Replace deprecated CPU-hotplug functions.
Date: Tue,  3 Aug 2021 16:16:07 +0200	[thread overview]
Message-ID: <20210803141621.780504-25-bigeasy@linutronix.de> (raw)
In-Reply-To: <20210803141621.780504-1-bigeasy-hfZtesqFncYOwBW4kG4KsQ@public.gmane.org>

The functions get_online_cpus() and put_online_cpus() have been
deprecated during the CPU hotplug rework. They map directly to
cpus_read_lock() and cpus_read_unlock().

Replace deprecated CPU-hotplug functions with the official version.
The behavior remains unchanged.

Cc: Zefan Li <lizefan.x-EC8Uxl6Npydl57MIdRCFDg@public.gmane.org>
Cc: Tejun Heo <tj-DgEjT+Ai2ygdnm+yROfE0A@public.gmane.org>
Cc: Johannes Weiner <hannes-druUgvl0LCNAfugRpC6u6w@public.gmane.org>
Cc: cgroups-u79uwXL29TY76Z2rM5mHXA@public.gmane.org
Signed-off-by: Sebastian Andrzej Siewior <bigeasy-hfZtesqFncYOwBW4kG4KsQ@public.gmane.org>
---
 kernel/cgroup/cpuset.c | 30 +++++++++++++++---------------
 1 file changed, 15 insertions(+), 15 deletions(-)

diff --git a/kernel/cgroup/cpuset.c b/kernel/cgroup/cpuset.c
index adb5190c44296..bd2b998249e8b 100644
--- a/kernel/cgroup/cpuset.c
+++ b/kernel/cgroup/cpuset.c
@@ -979,7 +979,7 @@ partition_and_rebuild_sched_domains(int ndoms_new, cpumask_var_t doms_new[],
  * 'cpus' is removed, then call this routine to rebuild the
  * scheduler's dynamic sched domains.
  *
  * Call with cpuset_mutex held.  Takes get_online_cpus().
  */
 static void rebuild_sched_domains_locked(void)
 {
@@ -1040,11 +1040,11 @@ static void rebuild_sched_domains_locked(void)
 
 void rebuild_sched_domains(void)
 {
-	get_online_cpus();
+	cpus_read_lock();
 	percpu_down_write(&cpuset_rwsem);
 	rebuild_sched_domains_locked();
 	percpu_up_write(&cpuset_rwsem);
-	put_online_cpus();
+	cpus_read_unlock();
 }
 
 /**
@@ -2282,7 +2282,7 @@ static int cpuset_write_u64(struct cgroup_subsys_state *css, struct cftype *cft,
 	cpuset_filetype_t type = cft->private;
 	int retval = 0;
 
-	get_online_cpus();
+	cpus_read_lock();
 	percpu_down_write(&cpuset_rwsem);
 	if (!is_cpuset_online(cs)) {
 		retval = -ENODEV;
@@ -2320,7 +2320,7 @@ static int cpuset_write_u64(struct cgroup_subsys_state *css, struct cftype *cft,
 	}
 out_unlock:
 	percpu_up_write(&cpuset_rwsem);
-	put_online_cpus();
+	cpus_read_unlock();
 	return retval;
 }
 
@@ -2331,7 +2331,7 @@ static int cpuset_write_s64(struct cgroup_subsys_state *css, struct cftype *cft,
 	cpuset_filetype_t type = cft->private;
 	int retval = -ENODEV;
 
-	get_online_cpus();
+	cpus_read_lock();
 	percpu_down_write(&cpuset_rwsem);
 	if (!is_cpuset_online(cs))
 		goto out_unlock;
@@ -2346,7 +2346,7 @@ static int cpuset_write_s64(struct cgroup_subsys_state *css, struct cftype *cft,
 	}
 out_unlock:
 	percpu_up_write(&cpuset_rwsem);
-	put_online_cpus();
+	cpus_read_unlock();
 	return retval;
 }
 
@@ -2385,7 +2385,7 @@ static ssize_t cpuset_write_resmask(struct kernfs_open_file *of,
 	kernfs_break_active_protection(of->kn);
 	flush_work(&cpuset_hotplug_work);
 
-	get_online_cpus();
+	cpus_read_lock();
 	percpu_down_write(&cpuset_rwsem);
 	if (!is_cpuset_online(cs))
 		goto out_unlock;
@@ -2411,7 +2411,7 @@ static ssize_t cpuset_write_resmask(struct kernfs_open_file *of,
 	free_cpuset(trialcs);
 out_unlock:
 	percpu_up_write(&cpuset_rwsem);
-	put_online_cpus();
+	cpus_read_unlock();
 	kernfs_unbreak_active_protection(of->kn);
 	css_put(&cs->css);
 	flush_workqueue(cpuset_migrate_mm_wq);
@@ -2542,7 +2542,7 @@ static ssize_t sched_partition_write(struct kernfs_open_file *of, char *buf,
 		return -EINVAL;
 
 	css_get(&cs->css);
-	get_online_cpus();
+	cpus_read_lock();
 	percpu_down_write(&cpuset_rwsem);
 	if (!is_cpuset_online(cs))
 		goto out_unlock;
@@ -2550,7 +2550,7 @@ static ssize_t sched_partition_write(struct kernfs_open_file *of, char *buf,
 	retval = update_prstate(cs, val);
 out_unlock:
 	percpu_up_write(&cpuset_rwsem);
-	put_online_cpus();
+	cpus_read_unlock();
 	css_put(&cs->css);
 	return retval ?: nbytes;
 }
@@ -2756,7 +2756,7 @@ static int cpuset_css_online(struct cgroup_subsys_state *css)
 	if (!parent)
 		return 0;
 
-	get_online_cpus();
+	cpus_read_lock();
 	percpu_down_write(&cpuset_rwsem);
 
 	set_bit(CS_ONLINE, &cs->flags);
@@ -2809,7 +2809,7 @@ static int cpuset_css_online(struct cgroup_subsys_state *css)
 	spin_unlock_irq(&callback_lock);
 out_unlock:
 	percpu_up_write(&cpuset_rwsem);
-	put_online_cpus();
+	cpus_read_unlock();
 	return 0;
 }
 
@@ -2828,7 +2828,7 @@ static void cpuset_css_offline(struct cgroup_subsys_state *css)
 {
 	struct cpuset *cs = css_cs(css);
 
-	get_online_cpus();
+	cpus_read_lock();
 	percpu_down_write(&cpuset_rwsem);
 
 	if (is_partition_root(cs))
@@ -2849,7 +2849,7 @@ static void cpuset_css_offline(struct cgroup_subsys_state *css)
 	clear_bit(CS_ONLINE, &cs->flags);
 
 	percpu_up_write(&cpuset_rwsem);
-	put_online_cpus();
+	cpus_read_unlock();
 }
 
 static void cpuset_css_free(struct cgroup_subsys_state *css)
@@ -979,7 +979,7 @@ partition_and_rebuild_sched_domains(int ndoms_new, cpumask_var_t doms_new[],
  * scheduler's dynamic sched domains.
  *
- * Call with cpuset_mutex held.  Takes get_online_cpus().
+ * Call with cpuset_mutex held.  Takes cpus_read_lock().
  */
 static void rebuild_sched_domains_locked(void)
-- 
2.32.0


  parent reply	other threads:[~2021-08-03 14:18 UTC|newest]

Thread overview: 122+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2021-08-03 14:15 [PATCH 00/38] Replace deprecated CPU-hotplug Sebastian Andrzej Siewior
2021-08-03 14:15 ` Sebastian Andrzej Siewior
2021-08-03 14:15 ` Sebastian Andrzej Siewior
2021-08-03 14:15 ` Sebastian Andrzej Siewior
2021-08-03 14:15 ` [Nouveau] " Sebastian Andrzej Siewior
2021-08-03 14:15 ` Sebastian Andrzej Siewior
2021-08-03 14:15 ` [PATCH 01/38] Documentation: Replace deprecated CPU-hotplug functions Sebastian Andrzej Siewior
2021-08-27 23:53   ` [tip: smp/core] " tip-bot2 for Sebastian Andrzej Siewior
2021-08-03 14:15 ` [PATCH 02/38] MIPS: " Sebastian Andrzej Siewior
2021-08-05  9:02   ` Thomas Bogendoerfer
2021-08-03 14:15 ` [PATCH 03/38] powerpc: " Sebastian Andrzej Siewior
2021-08-03 14:15   ` Sebastian Andrzej Siewior
2021-08-03 14:15   ` Sebastian Andrzej Siewior
2021-08-03 14:15 ` [PATCH 04/38] s390: " Sebastian Andrzej Siewior
2021-08-03 15:40   ` Heiko Carstens
2021-08-03 14:15 ` [PATCH 05/38] s390/sclp: " Sebastian Andrzej Siewior
2021-08-03 15:40   ` Heiko Carstens
2021-08-03 14:15 ` [PATCH 06/38] x86/mmiotrace: " Sebastian Andrzej Siewior
2021-08-03 14:15   ` [Nouveau] " Sebastian Andrzej Siewior
2021-08-03 15:03   ` Karol Herbst
2021-08-03 15:03     ` Karol Herbst
2021-08-04  1:07   ` Steven Rostedt
2021-08-04  1:07     ` [Nouveau] " Steven Rostedt
2021-08-10 12:52   ` [tip: x86/cleanups] " tip-bot2 for Sebastian Andrzej Siewior
2021-08-03 14:15 ` [PATCH 07/38] x86/mtrr: " Sebastian Andrzej Siewior
2021-08-10 12:52   ` [tip: x86/cleanups] " tip-bot2 for Sebastian Andrzej Siewior
2021-08-03 14:15 ` [PATCH 08/38] x86/microcode: " Sebastian Andrzej Siewior
2021-08-10 12:52   ` [tip: x86/cleanups] " tip-bot2 for Sebastian Andrzej Siewior
2021-08-03 14:15 ` [PATCH 09/38] x86/mce/inject: " Sebastian Andrzej Siewior
2021-08-10 12:52   ` [tip: x86/cleanups] " tip-bot2 for Sebastian Andrzej Siewior
2021-08-03 14:15 ` [PATCH 10/38] perf/x86/intel: " Sebastian Andrzej Siewior
2021-08-10 13:04   ` [tip: perf/core] " tip-bot2 for Sebastian Andrzej Siewior
2021-08-26  8:09   ` tip-bot2 for Sebastian Andrzej Siewior
2021-08-03 14:15 ` [PATCH 11/38] perf/hw_breakpoint: " Sebastian Andrzej Siewior
2021-08-10 13:04   ` [tip: perf/core] " tip-bot2 for Sebastian Andrzej Siewior
2021-08-26  8:09   ` tip-bot2 for Sebastian Andrzej Siewior
2021-08-03 14:15 ` [PATCH 12/38] crypto: virtio: " Sebastian Andrzej Siewior
2021-08-03 14:15   ` Sebastian Andrzej Siewior
2021-08-12 11:36   ` Herbert Xu
2021-08-12 11:36     ` Herbert Xu
2021-08-03 14:15 ` [PATCH 13/38] hwmon: " Sebastian Andrzej Siewior
2021-08-03 15:29   ` Guenter Roeck
2021-08-03 14:15 ` [PATCH 14/38] coresight: " Sebastian Andrzej Siewior
2021-08-03 14:15   ` Sebastian Andrzej Siewior
2021-08-03 15:52   ` Mathieu Poirier
2021-08-03 15:52     ` Mathieu Poirier
2021-08-03 14:15 ` [PATCH 15/38] md/raid5: " Sebastian Andrzej Siewior
2021-08-05 16:20   ` Song Liu
2021-08-27 23:53   ` [tip: smp/core] " tip-bot2 for Sebastian Andrzej Siewior
2021-08-03 14:15 ` [PATCH 16/38] sgi-xpc: " Sebastian Andrzej Siewior
2021-08-03 15:54   ` Steve Wahl
2021-08-03 21:30   ` Robin Holt
2021-08-03 14:16 ` [PATCH 17/38] platform/x86: " Sebastian Andrzej Siewior
2021-08-06 13:36   ` Hans de Goede
2021-08-03 14:16 ` [PATCH 18/38] powercap: intel_rapl: " Sebastian Andrzej Siewior
2021-08-04 18:14   ` Rafael J. Wysocki
2021-08-03 14:16 ` [PATCH 19/38] thermal: " Sebastian Andrzej Siewior
2021-08-14 10:52   ` Daniel Lezcano
2021-09-09 14:38   ` [thermal: thermal/next] thermal/drivers/intel_powerclamp: " thermal-bot for Sebastian Andrzej Siewior
2021-09-10 22:45   ` [tip: smp/urgent] thermal: " tip-bot2 for Sebastian Andrzej Siewior
2021-09-11 20:48     ` Daniel Lezcano
2021-09-11 21:11       ` Borislav Petkov
2021-08-03 14:16 ` [PATCH 20/38] mm: " Sebastian Andrzej Siewior
2021-08-27 23:53   ` [tip: smp/core] " tip-bot2 for Sebastian Andrzej Siewior
2021-08-03 14:16 ` [PATCH 21/38] virtio_net: " Sebastian Andrzej Siewior
2021-08-03 14:16   ` Sebastian Andrzej Siewior
2021-08-04 22:41   ` Jakub Kicinski
2021-08-03 14:16 ` [PATCH 22/38] net/af_iucv: " Sebastian Andrzej Siewior
2021-08-04  6:36   ` Julian Wiedmann
2021-08-03 14:16 ` [PATCH 23/38] net: " Sebastian Andrzej Siewior
2021-08-03 14:16 ` Sebastian Andrzej Siewior [this message]
2021-08-03 14:16   ` [PATCH 24/38] cgroup: " Sebastian Andrzej Siewior
2021-08-09 22:37   ` Tejun Heo
2021-08-09 22:37     ` Tejun Heo
2021-08-03 14:16 ` [PATCH 25/38] genirq/affinity: " Sebastian Andrzej Siewior
2021-08-10 12:58   ` [tip: irq/core] " tip-bot2 for Sebastian Andrzej Siewior
2021-08-03 14:16 ` [PATCH 26/38] livepatch: " Sebastian Andrzej Siewior
2021-08-04  7:52   ` Petr Mladek
2021-08-19 10:01     ` Jiri Kosina
2021-08-03 14:16 ` [PATCH 27/38] padata: " Sebastian Andrzej Siewior
2021-08-04 14:52   ` Daniel Jordan
2021-08-12 11:36   ` Herbert Xu
2021-08-03 14:16 ` [PATCH 28/38] cpufreq: " Sebastian Andrzej Siewior
2021-08-04 18:19   ` Rafael J. Wysocki
2021-08-03 14:16 ` [PATCH 29/38] ACPI: processor: " Sebastian Andrzej Siewior
2021-08-04 18:27   ` Rafael J. Wysocki
2021-08-03 14:16 ` [PATCH 30/38] ACPI: PM: s2idle: " Sebastian Andrzej Siewior
2021-08-04 18:20   ` Rafael J. Wysocki
2021-08-03 14:16 ` [PATCH 31/38] rcu: " Sebastian Andrzej Siewior
2021-08-03 16:00   ` Paul E. McKenney
2021-08-10 12:42     ` Thomas Gleixner
2021-08-10 18:20       ` Paul E. McKenney
2021-08-03 14:16 ` [PATCH 32/38] sched: " Sebastian Andrzej Siewior
2021-08-10 12:58   ` [tip: sched/core] " tip-bot2 for Sebastian Andrzej Siewior
2021-08-03 14:16 ` [PATCH 33/38] smpboot: " Sebastian Andrzej Siewior
2021-08-10 13:04   ` [tip: smp/core] " tip-bot2 for Sebastian Andrzej Siewior
2021-08-03 14:16 ` [PATCH 34/38] clocksource: " Sebastian Andrzej Siewior
2021-08-10 12:58   ` [tip: timers/core] " tip-bot2 for Sebastian Andrzej Siewior
2021-08-03 14:16 ` [PATCH 35/38] torture: " Sebastian Andrzej Siewior
2021-08-03 14:16 ` [PATCH 36/38] tracing: " Sebastian Andrzej Siewior
2021-08-03 15:16   ` Daniel Bristot de Oliveira
2021-08-04  2:26   ` Steven Rostedt
2021-08-10 13:34     ` Sebastian Andrzej Siewior
2021-08-10 19:12       ` Steven Rostedt
2021-08-03 14:16 ` [PATCH 37/38] workqueue: " Sebastian Andrzej Siewior
2021-08-04  1:36   ` Lai Jiangshan
2021-08-09 22:33   ` Tejun Heo
2021-08-03 14:16 ` [PATCH 38/38] cpu/hotplug: Remove " Sebastian Andrzej Siewior
2021-09-10 22:45   ` [tip: smp/urgent] " tip-bot2 for Sebastian Andrzej Siewior
2021-08-03 15:30 ` [PATCH 00/38] Replace deprecated CPU-hotplug Hans de Goede
2021-08-03 15:30   ` Hans de Goede
2021-08-03 15:30   ` Hans de Goede
2021-08-03 15:30   ` Hans de Goede
2021-08-03 15:30   ` [Nouveau] " Hans de Goede
2021-08-03 15:30   ` Hans de Goede
2021-08-03 16:10   ` Sebastian Andrzej Siewior
2021-08-03 16:10     ` Sebastian Andrzej Siewior
2021-08-03 16:10     ` Sebastian Andrzej Siewior
2021-08-03 16:10     ` Sebastian Andrzej Siewior
2021-08-03 16:10     ` [Nouveau] " Sebastian Andrzej Siewior
2021-08-03 16:10     ` Sebastian Andrzej Siewior
2021-08-18 13:38 ` (subset) " Michael Ellerman

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20210803141621.780504-25-bigeasy@linutronix.de \
    --to=bigeasy@linutronix.de \
    --cc=cgroups@vger.kernel.org \
    --cc=hannes@cmpxchg.org \
    --cc=linux-kernel@vger.kernel.org \
    --cc=lizefan.x@bytedance.com \
    --cc=peterz@infradead.org \
    --cc=tglx@linutronix.de \
    --cc=tj@kernel.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.